==> converter-0.2.0.tar.gz: test/quantities/base/length_testcase.dart <==
import 'package:converter/converter.dart';

final Map<String, dynamic> lengthConverter = <String, dynamic>{
  'testCases': <Map<String, dynamic>>[
    <String, dynamic>{
      'quantity': Length.si(2),
      'magnitudeInSI': 2,
      'magnitudeIn': <String, num>{
        'm': 2,
        'dm': 20,
        'cm': 200,
        'mm': 2000,
        'µm': 2e6,
        'nm': 2e9,
        'dam': 0.2,
        'hm': 0.02,
        'km': 0.002,
        'Mm': 2e-6,
        'Gm': 2e-9,
        'Å': 2e10,
        'in': 78.740157,
        'ft': 6.561679,
        'yd': 2.187226,
        'mi': 0.001242742,
        'nmi': 0.001079913,
      },
    },
    <String, dynamic>{
      'quantity': Length(3, 'nm'),
      'magnitudeInSI': 3e-9,
      'magnitudeIn': <String, num>{
        'm': 3e-9,
        'dm': 3e-8,
        'cm': 3e-7,
        'mm': 3e-6,
        'µm': 0.003,
        'nm': 3,
        'dam': 3e-10,
        'hm': 3e-11,
        'km': 3e-12,
        'Mm': 3e-15,
        'Gm': 3e-18,
        'Å': 30,
        'in': 1.181102e-7,
        'ft': 9.842519e-9,
        'yd': 3.280839e-9,
        'mi': 1.864113e-12,
        'nmi': 1.619870e-12,
      },
    },
    <String, dynamic>{
      'quantity': Length(5, 'Gm'),
      'magnitudeInSI': 5e9,
      'magnitudeIn': <String, num>{
        'm': 5e9,
        'dm': 5e10,
        'cm': 5e11,
        'mm': 5e12,
        'µm': 5e15,
        'nm': 5e18,
        'dam': 5e8,
        'hm': 5e7,
        'km': 5e6,
        'Mm': 5000,
        'Gm': 5,
        'Å': 5e19,
        'in': 1.968504e11,
        'ft': 1.640420e10,
        'yd': 5.468066e9,
        'mi': 3.106855e6,
        'nmi': 2.699784e6,
      },
    },
  ],
};

==> converter-0.3.4.tar.gz: test/quantities/base/length_testcase.dart <==
import 'package:converter/converter.dart';

final Map<String, dynamic> lengthConverter = <String, dynamic>{
  'testCases': <Map<String, dynamic>>[
    <String, dynamic>{
      'quantity': Length.si(2),
      'siValue': 2,
      'valueIn': <String, num>{
        'm': 2,
        'dm': 20,
        'cm': 200,
        'mm': 2000,
        'µm': 2e6,
        'nm': 2e9,
        'dam': 0.2,
        'hm': 0.02,
        'km': 0.002,
        'Mm': 2e-6,
        'Gm': 2e-9,
        'Å': 2e10,
        'in': 78.740157,
        'ft': 6.561679,
        'yd': 2.187226,
        'mi': 0.001242742,
        'nmi': 0.001079913,
      },
    },
    <String, dynamic>{
      'quantity': Length(3, 'nm'),
      'siValue': 3e-9,
      'valueIn': <String, num>{
        'm': 3e-9,
        'dm': 3e-8,
        'cm': 3e-7,
        'mm': 3e-6,
        'µm': 0.003,
        'nm': 3,
        'dam': 3e-10,
        'hm': 3e-11,
        'km': 3e-12,
        'Mm': 3e-15,
        'Gm': 3e-18,
        'Å': 30,
        'in': 1.181102e-7,
        'ft': 9.842519e-9,
        'yd': 3.280839e-9,
        'mi': 1.864113e-12,
        'nmi': 1.619870e-12,
      },
    },
    <String, dynamic>{
      'quantity': Length(5, 'Gm'),
      'siValue': 5e9,
      'valueIn': <String, num>{
        'm': 5e9,
        'dm': 5e10,
        'cm': 5e11,
        'mm': 5e12,
        'µm': 5e15,
        'nm': 5e18,
        'dam': 5e8,
        'hm': 5e7,
        'km': 5e6,
        'Mm': 5000,
        'Gm': 5,
        'Å': 5e19,
        'in': 1.968504e11,
        'ft': 1.640420e10,
        'yd': 5.468066e9,
        'mi': 3.106855e6,
        'nmi': 2.699784e6,
      },
    },
  ],
};
